@@ -13,7 +13,7 @@ def render_directive_matches(directive_matches: List[NginxLineConfig]):
         logger.debug(f"Rendering line config {line_config}")
         file_line = f"{line_config.file}:{line_config.line}"
         values = " ".join(line_config.args)
-        parent_blocks = " -> ".join(line_config.parent_blocks)
+        parent_blocks = " -> ".join(line_config.lineage)
         directives_table.add_row([file_line, values, parent_blocks])
 
     logger.info(directives_table)
